.. _auto_file-name:

!!!!!!!!!
auto_file
!!!!!!!!!

.. meta::
   :keywords: auto_file, automatically, generated, files

.. index:: auto_file, automatically, generated, files

.. _auto_file-title:

Automatically Generated Files
#############################
These files are located in the :ref:`config_file@directory@rst_directory` .
A new version of these files is created each time ``xrst`` is run.
The files in the ``rst`` subdirectory that do not change are not replaced.
(This reduces the amount of processing that sphinx needs to do.)

.. contents::
   :local:

.. meta::
   :keywords: conf.py

.. index:: conf.py

.. _auto_file@conf.py:

conf.py
*******
This is the sphinx configuration_ file.
It is the only file in the *rst_directory* directory that is
not an rst file.

.. _configuration:  http://www.sphinx-doc.org/en/master/config

.. meta::
   :keywords: xrst_root_doc.rst

.. index:: xrst_root_doc.rst

.. _auto_file@xrst_root_doc.rst:

xrst_root_doc.rst
*****************
This file is the top of the documentation tree
built by sphinx. It is one level above the first page in
:ref:`config_file@root_file`.

.. meta::
   :keywords: xrst_table_of_contents.rst

.. index:: xrst_table_of_contents.rst

.. _auto_file@xrst_table_of_contents.rst:

xrst_table_of_contents.rst
**************************
This file contains the table of contents for the last run of ``xrst``.
You can link to the corresponding page with the following command::

   :ref:`xrst_table_of_contents-title`

The result of this command in this documentation is
:ref:`xrst_table_of_contents-title` .

.. meta::
   :keywords: xrst_index.rst

.. index:: xrst_index.rst

.. _auto_file@xrst_index.rst:

xrst_index.rst
**************
If :ref:`run_xrst@target` is html,
this file contains a link to the table of contents generated by sphinx.
To be specific:

   :ref:`link to index<genindex>`

The xrst_index.rst file is not created when target is tex.
